Page 90 of The Secret Side Of History Mystery Babylon, 209P | thedailydialectics
Description: Document: The Secret Side Of History Mystery Babylon, 209P
Keywords: The Secret Side Of History Mystery Babylon, 209P

# The Secret Side Of History Mystery Babylon, 209P — Page 90

Home

    When inflation really becomes rampant, when it gets
    to the point where people literally have to rush to the
    grocery stores with their paychecks in order to buy food,
    because if they wait until the next day the price will have
    gone up on a loaf of bread, and their paycheck will no
    longer be as valuable 24 hours later, when it gets to the
    point where people are having their savings literally
    wiped out because the value of the money that they have
    in savings is falling so rapidly, then it's important for the
    government to have to do something to supposedly cure
    this problem. Well, the fact of the matter is, the
    government is the culprit, or the entity that created the
    problem in the first place.

    I think somewhere down the line when inflation heats

    up here in the United States, and it becomes more
    obvious that it is something of concern, the government
    will be expected to do something about it, and one of the
    things they will probably do is issue a new currency .. .

    The most important function to be served by the new
    monetary unit, or this new currency we are talking
    about, is a transition to a true world monetary unit, or a
    world currency.

    The bottom line of all this, is that we are headed, if
    we don't do something about it, directly into a one world
    government. One of the most obvious evidences of a
    one world government is a one world monetary unit.’

    Nothing is going to happen in the realm of political
    change unless Congress makes it happen. Congress is the
    body that makes the rules. So nothing is going to change

    85

    Building Modern Babylon

    As a solution to this manufactured crisis Mr. Griffin

    had this to say: